@@ -77,7 +77,7 @@
 #' binary variables (e.g., using \code{\link{Untoggle}}).
 #'
 #' @author Zhang, Z., Charlton, C.M.J., Parker, R.M.A., Leckie, G., and Browne,
-#' W.J. (2015) Centre for Multilevel Modelling, University of Bristol.
+#' W.J. (2016) Centre for Multilevel Modelling, University of Bristol.
 #'
 #' @seealso
 #' \code{\link{runMLwiN}}, \code{\link{write.IGLS}}, \code{\link{write.MCMC}}, \code{\link{Formula.translate}}
@@ -1005,6 +1005,8 @@ Formula.translate.compat <- function(Formula, levID, D = "Normal", indata) {
       invars$rp <- rp
     if (length(nonfps) != 0)
       invars$nonfp <- nonfps
+    invars$contrasts <- list()
+    invars$xlevels <- list()
     invars$D <- D
     if (!is.null(categ))
       invars$categ <- categ
